@@ -1,6 +1,6 @@
 import os
 import sys
-from datetime import datetime
+from datetime import datetime, timezone
 from io import StringIO
 from unittest import TestCase
 
@@ -17,7 +17,7 @@ class TestCliUtil(TestCase):
         assert json_encode(get_func_and_args) == "Function: get_func_and_args"
 
     def test_json_encode_datetime(self):
-        now = datetime.utcnow()
+        now = datetime.now(timezone.utc)
         assert json_encode(now) == now.isoformat()
 
     def test_json_encode_file(self):
@@ -30,15 +30,13 @@ class TestCliUtil(TestCase):
     def test_setup_no_module(self):
         with self.assertRaises(CliError) as context:
             get_func_and_args(("no.op",))
-        assert context.exception.message == "No such module: pyinfra.operations.no"
+        assert context.exception.message == "No such module: no"
 
     def test_setup_no_op(self):
         with self.assertRaises(CliError) as context:
             get_func_and_args(("server.no",))
 
-        assert (
-            context.exception.message == "No such attribute in module pyinfra.operations.server: no"
-        )
+        assert context.exception.message == "No such attribute in module server: no"
 
     def test_setup_op_and_args(self):
         commands = ("pyinfra.operations.server.user", "one", "two", "hello=world")
